==> upload-api-client-internal-2.39.0.tgz: package/src/services/UploadsService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { BeginMultipartUploadRequestV2 } from "../models/BeginMultipartUploadRequestV2";
import type { BeginMultipartUploadResponseV2 } from "../models/BeginMultipartUploadResponseV2";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { UploadId } from "../models/UploadId";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV2 } from "../models/UploadPartV2";
import { request as __request } from "../core/request";

export class UploadsService {
  /**
   * Initializes a new multipart file upload session.
   *
   * See also: basic file uploads.
   * @param accountId
   * @param requestBody File upload parameters.
   * @returns BeginMultipartUploadResponseV2 Success.
   * @throws ApiError
   */
  public static async beginMultipartUpload(
    accountId: AccountId,
    requestBody: BeginMultipartUploadRequestV2
  ): Promise<BeginMultipartUploadResponseV2> {
    const result = await __request({
      method: "POST",
      path: `/v2/accounts/${accountId}/uploads`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Finalizes an upload part for an in-progress multipart file upload.
   * @param accountId
   * @param uploadId
   * @param uploadPartIndex
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async completeUploadPart(
    accountId: AccountId,
    uploadId: UploadId,
    uploadPartIndex: UploadPartIndex,
    requestBody: CompleteUploadPartRequest
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v2/accounts/${accountId}/uploads/${uploadId}/parts/${uploadPartIndex}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload.
   * @param accountId
   * @param uploadId
   * @param uploadPartIndex
   * @returns UploadPartV2 Success.
   * @throws ApiError
   */
  public static async getUploadPart(
    accountId: AccountId,
    uploadId: UploadId,
    uploadPartIndex: UploadPartIndex
  ): Promise<UploadPartV2> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/uploads/${uploadId}/parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete.
   * @param accountId
   * @param uploadId
   * @returns UploadPartList Success.
   * @throws ApiError
   */
  public static async listUploadParts(accountId: AccountId, uploadId: UploadId): Promise<UploadPartList> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/uploads/${uploadId}/parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.43.0.tgz: package/src/services/UploadsService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { BeginMultipartUploadRequestV2 } from "../models/BeginMultipartUploadRequestV2";
import type { BeginMultipartUploadResponseV2 } from "../models/BeginMultipartUploadResponseV2";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { UploadId } from "../models/UploadId";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV2 } from "../models/UploadPartV2";
import { request as __request } from "../core/request";

export class UploadsService {
  /**
   * Begins a new multipart file upload process.
   *
   * See also: basic file uploads.
   * @param accountId
   * @param requestBody File upload parameters.
   * @returns BeginMultipartUploadResponseV2 Success.
   * @throws ApiError
   */
  public static async beginMultipartUpload(
    accountId: AccountId,
    requestBody: BeginMultipartUploadRequestV2
  ): Promise<BeginMultipartUploadResponseV2> {
    const result = await __request({
      method: "POST",
      path: `/v2/accounts/${accountId}/uploads`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Marks an upload part as uploaded.
   *
   * You must call this endpoint after you have successfully issued a `PUT` request to the `uploadUrl` on the corresponding UploadPart.
   * @param accountId
   * @param uploadId
   * @param uploadPartIndex
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async completeUploadPart(
    accountId: AccountId,
    uploadId: UploadId,
    uploadPartIndex: UploadPartIndex,
    requestBody: CompleteUploadPartRequest
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v2/accounts/${accountId}/uploads/${uploadId}/parts/${uploadPartIndex}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for a multipart file upload.
   * @param accountId
   * @param uploadId
   * @param uploadPartIndex
   * @returns UploadPartV2 Success.
   * @throws ApiError
   */
  public static async getUploadPart(
    accountId: AccountId,
    uploadId: UploadId,
    uploadPartIndex: UploadPartIndex
  ): Promise<UploadPartV2> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/uploads/${uploadId}/parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for a multipart file upload.
   *
   * An empty array is returned when the upload is complete.
   * @param accountId
   * @param uploadId
   * @returns UploadPartList Success.
   * @throws ApiError
   */
  public static async listUploadParts(accountId: AccountId, uploadId: UploadId): Promise<UploadPartList> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/uploads/${uploadId}/parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}
